.. _install:

Installation
============

**marshmallow** requires Python >= 3.5. It has no external dependencies.

Installing/Upgrading from the PyPI
----------------------------------

To install the latest stable version from the PyPI:

::

    $ pip install -U marshmallow

To install the latest pre-release version from the PyPI:

::

    $ pip install -U marshmallow --pre

Get the Bleeding Edge Version
-----------------------------

To get the latest development version of marshmallow, run

::

    $ pip install -U git+https://github.com/marshmallow-code/marshmallow.git@dev


.. seealso::

    Need help upgrading to newer releases? See the :doc:`Upgrading to Newer Releases <upgrading>` page.
